==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GdkPixbufDecoder__24GdkPixbufWriterSpi.h <==
// public class gnu.java.awt.peer.gtk.GdkPixbufDecoder$GdkPixbufWriterSpi

// class file dependencies
// @dep_class 51c4ac444b8041e9 gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class a9d92a58c03c7752 javax_imageio_spi_ImageReaderWriterSpi
// @dep_class ada75c9be7a822a4 javax_imageio_spi_ImageWriterSpi

// header file dependencies
// @dep_header javax_imageio_spi_ImageWriterSpi

#include "javax/imageio/spi/ImageWriterSpi.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi_H_
#define _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;
struct _jc_javax_imageio_ImageTypeSpecifier$object;
struct _jc_javax_imageio_ImageWriter$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24stream__24ImageOutputStream;
};
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *);

// Virtual methods
extern jboolean _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$canEncodeImage$3d4dd01ac474b41f(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
extern struct _jc_javax_imageio_ImageWriter$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$createWriterInstance$bf8889b8df993121(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$getDescription$e653ca2170cc9e26(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_util_Locale$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method_info$canEncodeImage$3d4dd01ac474b41f;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method_info$createWriterInstance$bf8889b8df993121;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method_info$getDescription$e653ca2170cc9e26;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods {
	jboolean	(*canEncodeImage$3d4dd01ac474b41f)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_javax_imageio_ImageTypeSpecifier$object *);
	struct _jc_javax_imageio_ImageWriter$object	*(*createWriterInstance$bf8889b8df993121)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getDescription$e653ca2170cc9e26)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_util_Locale$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageReaderWriterSpi$vmethods	javax_imageio_spi_ImageReaderWriterSpi;
	_jc_javax_imageio_spi_ImageWriterSpi$vmethods	javax_imageio_spi_ImageWriterSpi;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs {
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi;
    _jc_javax_imageio_spi_ImageWriterSpi$sub_refs	javax_imageio_spi_ImageWriterSpi;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_refs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_nonrefs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_ImageWriterSpi$sub_nonrefs	javax_imageio_spi_ImageWriterSpi;
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object {
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GdkPixbufDecoder__24GdkPixbufWriterSpi.h <==
// public class gnu.java.awt.peer.gtk.GdkPixbufDecoder$GdkPixbufWriterSpi

// class file dependencies
// @dep_class 51c4ac444b8041e9 gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class a9d92a58c03c7752 javax_imageio_spi_ImageReaderWriterSpi
// @dep_class ada75c9be7a822a4 javax_imageio_spi_ImageWriterSpi

// header file dependencies
// @dep_header javax_imageio_spi_ImageWriterSpi

#include "javax/imageio/spi/ImageWriterSpi.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi_H_
#define _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;
struct _jc_javax_imageio_ImageTypeSpecifier$object;
struct _jc_javax_imageio_ImageWriter$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24stream__24ImageOutputStream;
};
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$fields_struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$canEncodeImage$3d4dd01ac474b41f(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_imageio_ImageWriter$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$createWriterInstance$bf8889b8df993121(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$getDescription$e653ca2170cc9e26(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method_info$canEncodeImage$3d4dd01ac474b41f;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method_info$createWriterInstance$bf8889b8df993121;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method_info$getDescription$e653ca2170cc9e26;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods {
	jboolean	(*canEncodeImage$3d4dd01ac474b41f)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_javax_imageio_ImageTypeSpecifier$object *) _JC_JCNI_ATTR;
	struct _jc_javax_imageio_ImageWriter$object	*(*createWriterInstance$bf8889b8df993121)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getDescription$e653ca2170cc9e26)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageReaderWriterSpi$vmethods	javax_imageio_spi_ImageReaderWriterSpi;
	_jc_javax_imageio_spi_ImageWriterSpi$vmethods	javax_imageio_spi_ImageWriterSpi;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vmethods	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs {
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_refs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi;
    _jc_javax_imageio_spi_ImageWriterSpi$sub_refs	javax_imageio_spi_ImageWriterSpi;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_refs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_nonrefs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_ImageWriterSpi$sub_nonrefs	javax_imageio_spi_ImageWriterSpi;
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$sub_nonrefs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$object {
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$vtype _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufWriterSpi_H_ */
